@@ -2,7 +2,7 @@
 # -*- coding:utf-8 -*-
 '''
 @time   : 2020/10/20 19:13
-@file   : exec_shell.py
+@file   : shell.py
 @author : 
 @desc   : 
 @exec   : 
